Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2245)

Unified Diff: content/browser/web_contents/web_contents_impl.cc

Issue 2921823002: Rationalize WakeLock naming conventions (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/web_contents/web_contents_impl.h ('k') | content/browser/webrtc/webrtc_internals.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/web_contents/web_contents_impl.cc
diff --git a/content/browser/web_contents/web_contents_impl.cc b/content/browser/web_contents/web_contents_impl.cc
index 629c1f4823742feb0da62c7722e82e15677210e4..b185599107846cc73eb8007c8f56c751e0a39309 100644
--- a/content/browser/web_contents/web_contents_impl.cc
+++ b/content/browser/web_contents/web_contents_impl.cc
@@ -2642,10 +2642,10 @@ device::mojom::WakeLockContext* WebContentsImpl::GetWakeLockContext() {
return wake_lock_context_host_->GetWakeLockContext();
}
-device::mojom::WakeLockService* WebContentsImpl::GetRendererWakeLock() {
- // WebContents creates a long-lived connection to one WakeLockServiceImpl.
+device::mojom::WakeLock* WebContentsImpl::GetRendererWakeLock() {
+ // WebContents creates a long-lived connection to one WakeLock.
// All the frames' requests will be added into the BindingSet of
// WakeLockServiceImpl via this connection.
if (!renderer_wake_lock_) {
device::mojom::WakeLockContext* wake_lock_context = GetWakeLockContext();
if (!wake_lock_context) {
@@ -2642,10 +2642,10 @@ device::mojom::WakeLockContext* WebContentsImpl::GetWakeLockContext() {
// All the frames' requests will be added into the BindingSet of
- // WakeLockServiceImpl via this connection.
+ // WakeLock via this connection.
if (!renderer_wake_lock_) {
device::mojom::WakeLockContext* wake_lock_context = GetWakeLockContext();
« no previous file with comments | « content/browser/web_contents/web_contents_impl.h ('k') | content/browser/webrtc/webrtc_internals.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698